@@ -71,6 +71,7 @@ import com.openexchange.groupware.ldap.UserException;
 import com.openexchange.messaging.IndexRange;
 import com.openexchange.messaging.MessagingAccount;
 import com.openexchange.messaging.MessagingAddressHeader;
+import com.openexchange.messaging.MessagingContent;
 import com.openexchange.messaging.MessagingException;
 import com.openexchange.messaging.MessagingExceptionCodes;
 import com.openexchange.messaging.MessagingField;
@@ -78,6 +79,7 @@ import com.openexchange.messaging.MessagingFolder;
 import com.openexchange.messaging.MessagingHeader;
 import com.openexchange.messaging.MessagingMessage;
 import com.openexchange.messaging.MessagingMessageAccess;
+import com.openexchange.messaging.MessagingPart;
 import com.openexchange.messaging.OrderDirection;
 import com.openexchange.messaging.SearchTerm;
 import com.openexchange.messaging.StringContent;
@@ -88,6 +90,8 @@ import com.openexchange.messaging.facebook.utility.FacebookMessagingUtility;
 import com.openexchange.messaging.facebook.utility.FacebookUser;
 import com.openexchange.messaging.facebook.utility.FacebookMessagingUtility.Query;
 import com.openexchange.messaging.facebook.utility.FacebookMessagingUtility.StaticFiller;
+import com.openexchange.messaging.generic.AttachmentFinderHandler;
+import com.openexchange.messaging.generic.MessageParser;
 import com.openexchange.messaging.generic.MessagingComparator;
 import com.openexchange.messaging.generic.internet.MimeAddressMessagingHeader;
 import com.openexchange.server.ServiceException;
@@ -164,6 +168,16 @@ public final class FacebookMessagingMessageAccess implements MessagingMessageAcc
         return tmp;
     }
 
+    public MessagingPart getAttachment(final String folder, final String messageId, final String sectionId) throws MessagingException {
+        final AttachmentFinderHandler handler = new AttachmentFinderHandler(sectionId);
+        new MessageParser().parseMessage(getMessage(folder, messageId, true), handler);
+        final MessagingPart part = handler.getMessagingPart();
+        if (null == part) {
+            throw MessagingExceptionCodes.ATTACHMENT_NOT_FOUND.create(sectionId, messageId, folder);
+        }
+        return part;
+    }
+
     public void appendMessages(final String folder, final MessagingMessage[] messages) throws MessagingException {
         if (!EMPTY.equals(folder)) {
             throw MessagingExceptionCodes.FOLDER_NOT_FOUND.create(
@@ -625,4 +639,8 @@ public final class FacebookMessagingMessageAccess implements MessagingMessageAcc
         return facebookUserId;
     }
 
+    public MessagingContent resolveContent(final String folder, final String id, final String referenceId) throws MessagingException {
+        throw new UnsupportedOperationException();
+    }
+
 }
